@@ -163,9 +163,9 @@ name = "foo"
     doc = parse(content)
     unwrapped = doc.unwrap()
     assert_is_ppo(unwrapped, dict)
-    assert_is_ppo(list(unwrapped.keys())[0], str)
+    assert_is_ppo(next(iter(unwrapped)), str)
     assert_is_ppo(unwrapped["tool"], dict)
-    assert_is_ppo(list(unwrapped["tool"].keys())[0], str)
+    assert_is_ppo(next(iter(unwrapped["tool"])), str)
     assert_is_ppo(unwrapped["tool"]["poetry"]["name"], str)
 
 
@@ -676,6 +676,31 @@ z = 3
     assert json.dumps(document) == '{"a": {"x": 1}, "c": {"z": 3}}'
 
 
+def test_update_nested_out_of_order_table():
+    doc = parse("""\
+[root1.root2.a.b.c]
+  value = 2
+[WALRUS]
+  goo = "gjob"
+[root1.root2.x]
+  value = 4
+""")
+    doc["root1"]["root2"]["a"].add("tmp", "hi")
+    assert (
+        doc.as_string()
+        == """\
+[root1.root2.a]
+tmp = "hi"
+[root1.root2.a.b.c]
+  value = 2
+[WALRUS]
+  goo = "gjob"
+[root1.root2.x]
+  value = 4
+"""
+    )
+
+
 def test_updating_nested_value_keeps_correct_indent():
     content = """
 [Key1]
@@ -1084,3 +1109,81 @@ table = {a = 1, b = 2}
 age = 42
 """
     assert tomlkit.dumps(doc) == expected
+
+
+def test_delete_out_of_order_table_key():
+    content = """\
+[foo]
+name = "foo"
+
+[bar.a.b]
+name = "bar-a-b"
+
+[foo.a]
+name = "foo-a"
+
+[bar.a]
+name = "bar-a"
+
+[baz]
+name = "baz"
+
+[bar.a.c]
+name = "bar-a-c"
+"""
+    doc = parse(content)
+    del doc["bar"]["a"]
+    assert (
+        doc.as_string()
+        == """\
+[foo]
+name = "foo"
+
+[foo.a]
+name = "foo-a"
+
+[baz]
+name = "baz"
+
+"""
+    )
+
+
+def test_overwrite_out_of_order_table_key():
+    content = """\
+[foo]
+name = "foo"
+
+[bar.a.b]
+name = "bar-a-b"
+
+[foo.a]
+name = "foo-a"
+
+[bar.a]
+name = "bar-a"
+
+[baz]
+name = "baz"
+
+[bar.a.c]
+name = "bar-a-c"
+"""
+    doc = parse(content)
+    doc["bar"]["a"] = {"name": "bar-a-updated"}
+    assert (
+        doc.as_string()
+        == """\
+[foo]
+name = "foo"
+
+[bar.a]
+name = "bar-a-updated"
+[foo.a]
+name = "foo-a"
+
+[baz]
+name = "baz"
+
+"""
+    )
